
-- don't bother if no write access to rpmdb
if not posix.access("/var/lib/rpm", "w") then
	return
end

if confget("GPG::Import", "true") == "false" then
	return
end

if confexists("GPG::Dir") then
	keypath = confget("GPG::Dir")
else
	-- Default public gpg key directory
	keypath = confget("Dir::Etc/f").."gpg/"
end

keys = posix.dir(keypath)

if not keys then
	return
end

first = 1
success = 0
for i, key in ipairs(keys) do
	length = string.len(key)
	if string.sub(key, 1, 10) == "gpg-pubkey" or 
	  string.sub(key, length - 3, length) == ".asc" then

		gpgfile = io.open(keypath..key)
		for line in gpgfile.lines(gpgfile) do

			if string.find(line, "RPMDB_NAME") then
				rpmdb_name = string.gsub(line, "[ ]*RPMDB_NAME[ ]*=[ ]*", "")
				break
			end

			if string.find(line, "-----BEGIN PGP PUBLIC KEY BLOCK-----") then
				break
			end
print(line)
		end
		io.close(gpgfile)

		if not rpmdb_name then
			rpmdb_name = key
		end

		ret = os.execute("LANG=C rpm -q "..rpmdb_name.." > /dev/null 2>&1")
		if ret > 0 then
			if first then
				print(_("You don't seem to have one or more of the needed GPG keys in your RPM database."))
				print(_("Importing them now..."))
				first = nil
			end
			ret = os.execute("LANG=C rpm --import "..keypath..key.." > /dev/null 2>&1")
			if ret > 0 then
				print(_("Error importing GPG key: "..rpmdb_name))
				return
			end

			ret = os.execute("LANG=C rpm -q "..rpmdb_name.." > /dev/null 2>&1")
			if ret > 0 then
				print(_("GPG key not imported correctly"))
				print(_("GPG id: "..rpmdb_name))
				print(_("File: "..keypath..key))
				return
			else
				success = success + 1
			end
		end
	end
end

if success > 0 then
	if success == 1 then
		print(_("GPG key succesfully imported"))
	else
		print(_("All GPG keys succesfully imported"))
	end
end

-- vim:ts=4

